==> kmplayer_0.8.5-3.tar.gz: kmplayer-0.8.5/src/kmplayer_lists.h <==
/* This file is part of the KMPlayer project
 *
 * Copyright (C) 2006 Koos Vriezen <koos.vriezen@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Steet, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef _KMPLAYER_LISTS_H_
#define _KMPLAYER_LISTS_H_

#include "kmplayerplaylist.h"
#include "kmplayercontrol.h"

typedef struct _Application Application;

namespace KMPlayer {

static const short id_node_recent_document = 29;
static const short id_node_recent_node = 30;
static const short id_node_disk_document = 31;
static const short id_node_disk_node = 32;
static const short id_node_html_object = 33;
static const short id_node_html_embed = 34;

class KMPLAYER_NO_EXPORT FileDocument : public KMPlayer::SourceDocument {
public:
    FileDocument (short id, const String &, KMPlayer::Control * notify = 0L);
    KMPlayer::Node *childFromTag (const String & tag);
    void readFromFile (const String & file);
    void writeToFile (const String & file);
    unsigned int load_tree_version;
};


/*class KMPLAYER_NO_EXPORT ListsSource : public KMPlayer::URLSource {
public:
    KDE_NO_CDTOR_EXPORT ListsSource (KMPlayer::PartBase * p)
        : KMPlayer::URLSource (p, "lists://") {}
    void jump (KMPlayer::NodePtr e);
    void activate ();
    void setDocument (KMPlayer::NodePtr doc, KMPlayer::NodePtr cur);
    String prettyName () { return m_document->mrl ()->pretty_name; }
};*/

class KMPLAYER_NO_EXPORT Recents : public FileDocument {
public:
    Recents (Application *a);
    void defer ();
    void activate ();
    void *message (KMPlayer::MessageType msg, void *content=NULL);
    KMPlayer::Node *childFromTag (const String & tag);
    KDE_NO_EXPORT const char * nodeName () const { return "playlist"; }
    Application * app;
};

class KMPLAYER_NO_EXPORT Recent : public KMPlayer::Mrl {
public:
    Recent (KMPlayer::NodePtr & doc, Application *a, const String &url = String());
    void activate ();
    void closed ();
    KDE_NO_EXPORT const char * nodeName () const { return "item"; }
    Application * app;
};

class KMPLAYER_NO_EXPORT Group : public KMPlayer::Element {
public:
    Group (KMPlayer::NodePtr &doc, Application *a, const String &pn=String());
    KMPlayer::Node *childFromTag (const String & tag);
    void closed ();
    KDE_NO_EXPORT const char * nodeName () const { return "group"; }
    Application * app;
};

class KMPLAYER_NO_EXPORT Playlist : public FileDocument {
public:
    Playlist (Application *a, KMPlayer::Control *n, bool plmod = false);
    void *message (KMPlayer::MessageType msg, void *content=NULL);
    void defer ();
    void activate ();
    KMPlayer::Node *childFromTag (const String & tag);
    KDE_NO_EXPORT const char * nodeName () const { return "playlist"; }
    Application * app;
    String path;
    bool playmode;
};

class KMPLAYER_NO_EXPORT PlaylistItemBase : public KMPlayer::Mrl {
public:
    PlaylistItemBase (KMPlayer::NodePtr &d, short id, Application *a, bool pm);
    void activate ();
    void closed ();
    Application * app;
    bool playmode;
};

class KMPLAYER_NO_EXPORT PlaylistItem : public PlaylistItemBase {
public:
    PlaylistItem (KMPlayer::NodePtr & doc, Application *a, bool playmode, const String &url = String());
    void closed ();
    void begin ();
    void setNodeName (const String &);
    KDE_NO_EXPORT const char * nodeName () const { return "item"; }
};

class KMPLAYER_NO_EXPORT PlaylistGroup : public KMPlayer::Mrl {
public:
    PlaylistGroup (KMPlayer::NodePtr &doc, Application *a, const String &pn);
    PlaylistGroup (KMPlayer::NodePtr &doc, Application *a, bool plmode=false);
    KMPlayer::Node *childFromTag (const String & tag);
    void closed ();
    void setNodeName (const String &);
    KDE_NO_EXPORT const char * nodeName () const { return "group"; }
    Application * app;
    bool playmode;
};

class KMPLAYER_NO_EXPORT HtmlObject : public PlaylistItemBase {
public:
    HtmlObject (KMPlayer::NodePtr & doc, Application *a, bool playmode);
    void activate ();
    void closed ();
    KMPlayer::Node *childFromTag (const String & tag);
    KDE_NO_EXPORT const char * nodeName () const { return "object"; }
};

}  // KMPlayer namespace

#endif //_KMPLAYER_LISTS_H_

==> kmplayer_0.8.7-2.tar.gz: kmplayer-0.8.7/src/kmplayer_lists.h <==
/* This file is part of the KMPlayer project
 *
 * Copyright (C) 2006 Koos Vriezen <koos.vriezen@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Steet, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef _KMPLAYER_LISTS_H_
#define _KMPLAYER_LISTS_H_

#include "kmplayerplaylist.h"
#include "kmplayercontrol.h"

typedef struct _Application Application;

namespace KMPlayer {

static const short id_node_recent_document = 29;
static const short id_node_recent_node = 30;
static const short id_node_disk_document = 31;
static const short id_node_disk_node = 32;
static const short id_node_html_object = 33;
static const short id_node_html_embed = 34;

class KMPLAYER_NO_EXPORT FileDocument : public KMPlayer::SourceDocument {
public:
    FileDocument (short id, const String &, KMPlayer::Control * notify = 0L);
    KMPlayer::Node *childFromTag (const String & tag);
    void readFromFile (const String & file);
    void writeToFile (const String & file);
    unsigned int load_tree_version;
};


/*class KMPLAYER_NO_EXPORT ListsSource : public KMPlayer::URLSource {
public:
    KDE_NO_CDTOR_EXPORT ListsSource (KMPlayer::PartBase * p)
        : KMPlayer::URLSource (p, "lists://") {}
    void jump (KMPlayer::NodePtr e);
    void activate ();
    void setDocument (KMPlayer::NodePtr doc, KMPlayer::NodePtr cur);
    String prettyName () { return m_document->mrl ()->pretty_name; }
};*/

class KMPLAYER_NO_EXPORT Recents : public FileDocument {
public:
    Recents (Application *a);
    void defer ();
    void activate ();
    void *message (KMPlayer::MessageType msg, void *content=NULL);
    KMPlayer::Node *childFromTag (const String & tag);
    KDE_NO_EXPORT const char * nodeName () const { return "playlist"; }
    Application * app;
};

class KMPLAYER_NO_EXPORT Recent : public KMPlayer::Mrl {
public:
    Recent (KMPlayer::NodePtr & doc, Application *a, const String &url = String());
    void activate ();
    void closed ();
    KDE_NO_EXPORT const char * nodeName () const { return "item"; }
    Application * app;
};

class KMPLAYER_NO_EXPORT Group : public KMPlayer::Element {
public:
    Group (KMPlayer::NodePtr &doc, Application *a, const String &pn=String());
    KMPlayer::Node *childFromTag (const String & tag);
    void closed ();
    KDE_NO_EXPORT const char * nodeName () const { return "group"; }
    Application * app;
};

class KMPLAYER_NO_EXPORT Playlist : public FileDocument {
public:
    Playlist (Application *a, KMPlayer::Control *n, bool plmod = false);
    void *message (KMPlayer::MessageType msg, void *content=NULL);
    void defer ();
    void activate ();
    KMPlayer::Node *childFromTag (const String & tag);
    KDE_NO_EXPORT const char * nodeName () const { return "playlist"; }
    Application * app;
    String path;
    bool playmode;
};

class KMPLAYER_NO_EXPORT PlaylistItemBase : public KMPlayer::Mrl {
public:
    PlaylistItemBase (KMPlayer::NodePtr &d, short id, Application *a, bool pm);
    void activate ();
    void closed ();
    Application * app;
    bool playmode;
};

class KMPLAYER_NO_EXPORT PlaylistItem : public PlaylistItemBase {
public:
    PlaylistItem (KMPlayer::NodePtr & doc, Application *a, bool playmode, const String &url = String());
    void closed ();
    void begin ();
    void setNodeName (const String &);
    KDE_NO_EXPORT const char * nodeName () const { return "item"; }
};

class KMPLAYER_NO_EXPORT PlaylistGroup : public KMPlayer::Element {
public:
    PlaylistGroup (KMPlayer::NodePtr &doc, Application *a, const String &pn);
    PlaylistGroup (KMPlayer::NodePtr &doc, Application *a, bool plmode=false);
    KMPlayer::Node *childFromTag (const String & tag);
    void closed ();
    void setNodeName (const String &);
    KDE_NO_EXPORT const char * nodeName () const { return "group"; }
    Application * app;
    bool playmode;
};

class KMPLAYER_NO_EXPORT HtmlObject : public PlaylistItemBase {
public:
    HtmlObject (KMPlayer::NodePtr & doc, Application *a, bool playmode);
    void activate ();
    void closed ();
    KMPlayer::Node *childFromTag (const String & tag);
    KDE_NO_EXPORT const char * nodeName () const { return "object"; }
};

}  // KMPlayer namespace

#endif //_KMPLAYER_LISTS_H_
